@@ -14,12 +14,12 @@ from pathlib import Path
 from types import SimpleNamespace
 import zipfile
 from pathlib import Path
-import sysconfig
 
 from . import common
 from .templates import __version__
 from .xmake import XMaker
 from .builder.wheel_tag import WheelTag
+from .builder.builder import get_archs, archs_to_tags
 
 log = logging.getLogger(__name__)
 
@@ -118,18 +118,20 @@ class WheelBuilder:
         return common.dist_info_name(self.metadata.name, self.metadata.version)
 
     @property
-    def wheel_filename(self):
-        dist_name = common.normalize_dist_name(self.metadata.name, self.metadata.version)
+    def wheeltag(self):
         py_api = ""
         root_is_purelib = True
         if self.kind != 0:
             root_is_purelib = False
         if self.kind == 1:
             py_api = ('py2.' if self.metadata.supports_py2 else '') + 'py3'
-        archs = []
-        if sysconfig.get_platform().split("-")[-1] == "universal2":
-            archs = ["universal2"]
-        tag = str(WheelTag.compute_best(archs, py_api, root_is_purelib=root_is_purelib))
+        archs = archs_to_tags(get_archs(os.environ))
+        return WheelTag.compute_best(archs, py_api, root_is_purelib=root_is_purelib)
+
+    @property
+    def wheel_filename(self):
+        dist_name = common.normalize_dist_name(self.metadata.name, self.metadata.version)
+        tag = str(self.wheeltag)
         return '{}-{}.whl'.format(dist_name, tag)
 
     def _add_file(self, full_path, rel_path):
@@ -264,10 +266,10 @@ class WheelBuilder:
     def build(self, editable=False):
         with self.temp:
             if self.xmake:
-                self.xmake.config()
-                self.xmake.build()
-                self.xmake.install()
+                self.xmake.init()
                 self.kind = self.xmake.show()
+                self.xmake.package(self.wheeltag)
+                self.xmake.install()
             try:
                 if editable:
                     self.add_pth()
